package
Version:
v0.0.0-...-46fe30e
Opens a new window with list of versions in this module.
Published: Apr 8, 2016
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Test struct {
ID uint `gorm:"primary_key" json:"id"`
CreatedAt time.Time `json:"-"`
UpdatedAt time.Time `json:"-"`
Title string `json:"title"`
Description string `json:"description"`
Language string `json:"language"`
Source string `json:"source"`
Spec string `json:"spec"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.